# Changelog

## [0.3.0](https://github.com/aron98/better-mcps/compare/better-mcps-filesystem-v0.2.0...better-mcps-filesystem-v0.3.0) (2026-01-11)


### Features

* **filesystem:** pydantic-validated tool params; improve list_dir output; adjust python workflow ([ff42791](https://github.com/aron98/better-mcps/commit/ff42791ff6a5724bbfec01389017164d10ed1d4d))

## [0.2.0](https://github.com/aron98/better-mcps/compare/better-mcps-filesystem-v0.1.1...better-mcps-filesystem-v0.2.0) (2026-01-09)


### Features

* Improve list_dir ([#3](https://github.com/aron98/better-mcps/issues/3)) ([fd6453e](https://github.com/aron98/better-mcps/commit/fd6453e8d086f09b71b4eb178c3e541863415d20))

## [0.1.1](https://github.com/aron98/better-mcps/compare/better-mcps-filesystem-v0.1.0...better-mcps-filesystem-v0.1.1) (2026-01-09)


### Bug Fixes

* Unify ci ([#1](https://github.com/aron98/better-mcps/issues/1)) ([b62f045](https://github.com/aron98/better-mcps/commit/b62f045454134c76b35c9e08cd032c55a8363e6c))
